@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Rinci;
 
-our $DATE = '2015-03-08'; # DATE
-our $VERSION = '0.33'; # VERSION
+our $DATE = '2015-04-04'; # DATE
+our $VERSION = '0.34'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -70,12 +70,19 @@ sub _process_module {
         next unless $sectcontent =~ /\S/;
 
         # skip inserting FUNCTIONS if there are no functions
-        next if $sectname =~ /functions/i && $sectcontent !~ /^=head2/m;
+        next if $sectname eq 'FUNCTIONS' && $sectcontent !~ /^=head2/m;
 
         $found++;
         #$self->log(["generated POD section %s", $1]);
 
-        $self->add_text_to_section($document, $sectcontent, $sectname);
+        my %opts;
+        # position
+        if ($sectname eq 'FUNCTIONS') {
+            $opts{after_section} = ['DESCRIPTION'];
+            $opts{before_section} = ['HOMEPAGE'];
+        }
+
+        $self->add_text_to_section($document, $sectcontent, $sectname, \%opts);
     }
     if ($found) {
         $self->log(["added POD sections from Rinci metadata for module '%s'", $filename]);
@@ -238,7 +245,7 @@ sub _process_script {
         last unless @content;
 
         $self->add_text_to_section($document, join('', @content), 'SYNOPSIS',
-                                   {ignore=>1});
+                                   {ignore=>1, after_section=>['VERSION','NAME']});
         $modified++;
     }
 
@@ -253,7 +260,7 @@ sub _process_script {
         push @content, "\n\n";
 
         $self->add_text_to_section($document, join('', @content), 'DESCRIPTION',
-                                   {ignore=>1});
+                                   {ignore=>1, after_section=>['SYNOPSIS','VERSION','NAME']});
         $modified++;
     }
 
@@ -281,7 +288,7 @@ sub _process_script {
         }
 
         $self->add_text_to_section($document, join('', @content), 'SUBCOMMANDS',
-                                   {ignore=>1});
+                                   {ignore=>1, after_section=>['DESCRIPTION','SYNOPSIS']});
         $modified++;
     }
 
@@ -365,7 +372,7 @@ sub _process_script {
         }
 
         $self->add_text_to_section($document, join('', @content), 'OPTIONS',
-                                   {ignore=>1});
+                                   {ignore=>1, after_section=>['SUBCOMMANDS','DESCRIPTION']});
         $modified++;
     }
 
@@ -385,7 +392,8 @@ sub _process_script {
         my @content;
         push @content, $cli->env_name . "\n\n";
 
-        $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT');
+        $self->add_text_to_section($document, join('', @content), 'ENVIRONMENT',
+                                   {before_section=>'HOMEPAGE'});
         $modified++;
     }
 
@@ -404,13 +412,14 @@ sub _process_script {
         #$self->log_debug(["skipped file %s (script does not read config)", $filename]);
         my @content;
         my $config_filename = $cli->config_filename // $cli->program_name . ".conf";
-        my $config_dirs = $cli->{config_dirs} // ['~', '/etc'];
+        my $config_dirs = $cli->{config_dirs} // ['~/.config', '~', '/etc'];
 
         for my $config_dir (@{$config_dirs}) {
             push @content, "$config_dir/$config_filename\n\n";
         }
 
-        $self->add_text_to_section($document, join('', @content), 'FILES');
+        $self->add_text_to_section($document, join('', @content), 'FILES',
+                                   {after_section=>'ENVIRONMENT'});
         $modified++;
     }
 
@@ -468,7 +477,7 @@ Pod::Weaver::Plugin::Rinci - Insert stuffs to POD from Rinci metadata
 
 =head1 VERSION
 
-This document describes version 0.33 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-03-08.
+This document describes version 0.34 of Pod::Weaver::Plugin::Rinci (from Perl distribution Pod-Weaver-Plugin-Rinci), released on 2015-04-04.
 
 =head1 SYNOPSIS
 
@@ -565,7 +574,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/Pod-Weaver
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Perinci>.
+Source repository is at L<https://github.com/perlancar/perl-Pod-Weaver-Plugin-Rinci>.
 
 =head1 BUGS
 
